kmeans++ with return value similar to R kmeans
TGL_kmeans(
df,
k,
metric = "euclid",
max_iter = 40,
min_delta = 0.0001,
verbose = FALSE,
keep_log = FALSE,
id_column = FALSE,
reorder_func = "hclust",
hclust_intra_clusters = FALSE,
seed = NULL,
use_cpp_random = FALSE
)a data frame or a matrix. Each row is a single observation and each column is a dimension. the first column can contain id for each observation (if id_column is TRUE), otherwise the rownames are used.
number of clusters. Note that in some cases the algorithm might return fewer clusters than k.
distance metric for kmeans++ seeding. can be 'euclid', 'pearson' or 'spearman'
maximal number of iterations
minimal change in assignments (fraction out of all observations) to continue iterating
display algorithm messages
keep algorithm messages in 'log' field
df's first column contains the observation id. If not set and the first
column is character or factor, it will be automatically used as the ID column (with a warning).
function to reorder the clusters. operates on each center and orders by the result. e.g. reorder_func = mean would calculate the mean of each center and then would reorder the clusters accordingly. If reorder_func = hclust the centers would be ordered by hclust of the euclidean distance of the correlation matrix, i.e. hclust(dist(cor(t(centers))))
if NULL, no reordering would be done.
run hierarchical clustering within each cluster and return an ordering of the observations.
seed for the c++ random number generator
use c++ random number generator instead of R's. This should be used for only for backwards compatibility, as from version 0.4.0 onwards the default random number generator was changed to R.
list with the following components:
A vector of integers (from ‘1:k’) indicating the cluster to which each point is allocated.
A matrix of cluster centers.
The number of points in each cluster.
messages from the algorithm run (only if keep_log = TRUE).
A vector of integers with the new ordering if the observations. (only if hclust_intra_clusters = TRUE)
# create 5 clusters normally distributed around 1:5
d <- simulate_data(
n = 100,
sd = 0.3,
nclust = 5,
dims = 2,
add_true_clust = FALSE,
id_column = FALSE
)
head(d)
#> V1 V2
#> 1 0.5799869 0.8838359
#> 2 1.0765951 0.7643702
#> 3 0.2688209 0.6829789
#> 4 0.9983286 0.7613376
#> 5 1.1864658 0.4731174
#> 6 1.3445235 0.7928386
# cluster
km <- TGL_kmeans(d, k = 5, "euclid", verbose = TRUE)
#> generating 5 seeds
#> iteration 1: 2 reassignments
#> iteration 2: 0 reassignments
names(km)
#> [1] "cluster" "centers" "size"
km$centers
#> V1 V2
#> [1,] 2.964869 3.008410
#> [2,] 3.969391 4.038842
#> [3,] 1.019032 1.034553
#> [4,] 2.000776 2.053331
#> [5,] 4.975310 5.048907
head(km$cluster)
#> 1 2 3 4 5 6
#> 3 3 3 3 3 3
km$size
#> 1 2 3 4 5
#> 102 98 100 101 99